setwd("C:/sepp/work/fabia/experiments")


library(fabia)
library(biclust)
library(truecluster)
library(BicARE)


readPlaidResults <- function(filename,n,l,ab="ab",ss="ss",iter="default") {

    require(biclust)

    r1 <- readLines(filename)
    a1 <- strsplit(r1," ")

    la <- length(a1)
    p <- as.numeric(a1[[la-4]][1])

      if ((p==0)||(la==0)) {
        L <- matrix(0,n,1)
        Z <- matrix(0,1,l)
        p <- 0
    } else {


        L <- matrix(0,n,p)
        Z <- matrix(0,p,l)

        j <- 0
        r <- 0

        for (i in 1:la) {

            if (!is.na(a1[[i]][1]))
            {


                if (a1[[i]][1]=="row")
                {
                    j <- j+1
                    r <- 1
                }

                if (a1[[i]][1]=="col")
                {
                    r <- 2
                }

                if (a1[[i]][1]==as.character(j))
                {
                    if(r==1) {
                        L[as.numeric(a1[[i]][2]),j] <- 1
                    }
                    if(r==2) {
                        Z[j,as.numeric(a1[[i]][2])] <- 1
                    }
                }
            }
        }
    }

    pp<- list()
    pp[[1]]="plaid" # method
    pp[[2]]=ab    # a=alpha(probe) effects; b= beta(conditions) effects
    pp[[3]]=ss    # seek=ss prefer large, possibly diffuse layers
                    # seek=ms prefer intense, possibly small layers
    pp[[4]]=iter # how many seeking iterations

    bicB <- BiclustResult(pp,L,Z,p)

    return(bicB)
}


readBicatResults <- function(filename,n,l,method="isa",pre="standardization",tc="2.0",tg="2.0") {

    require(biclust)

    r1 <- readLines(filename)
    a1 <- strsplit(r1," ")

    la <- length(a1)
    p <- la/3

     if ((p==0)||(la==0)) {
        L <- matrix(0,n,1)
        Z <- matrix(0,1,l)
        p <- 0
    } else {

        L <- matrix(0,n,p)
        Z <- matrix(0,p,l)

        for (i in 1:p) {

            nn <- as.numeric(a1[[3*i-2]][1])
            nl <- as.numeric(a1[[3*i-2]][2])
            for (k in 1:nn) {
                L[as.numeric(a1[[3*i-1]][k]),i] <- 1
            }
            for (k in 1:nl) {
                Z[i,as.numeric(a1[[3*i]][k])] <- 1
            }
        }
    }

    pp<- list()
    pp[[1]]=method # method
    pp[[2]]=pre    # preprocessing: standardization
    pp[[3]]=tg     # gene score threshold
    pp[[4]]=tc     # condition score threshold

    bicB <- BiclustResult(pp,L,Z,p)

    return(bicB)
}


readSambaResults <- function(filename,n,l,pre="standardization",opt="valsp_3ap",over="0.5") {

    require(biclust)

    r1 <- readLines(filename)
    a1 <- strsplit(r1,"\t")

    la <- length(a1)

    s <- 1
    while ((a1[[s]][1]!="[Bicd]")&&(s<=la)) { s <- s+1 }

    p <- as.numeric(a1[[s-1]][1])+1

     if ((p==0)||(la==0)) {
        L <- matrix(0,n,1)
        Z <- matrix(0,1,l)
        p <- 0
    } else {
        L <- matrix(0,n,p)
        Z <- matrix(0,p,l)

        s <- s+1
        for (i in s:la) {

            if (a1[[i]][2]=="1") {
                L[as.numeric(a1[[i]][3]),(as.numeric(a1[[i]][1])+1)] <- 1
            }

            if (a1[[i]][2]=="0") {
                Z[(as.numeric(a1[[i]][1])+1),as.numeric(a1[[i]][3])] <- 1
            }
        }
    }

    pp<- list()
    pp[[1]]="samba" # method
    pp[[2]]=pre     # preprocessing: standardization
    pp[[3]]=opt     # options: valsp_3ap
    pp[[4]]=over    # overlap genes 0.1 or 0.5

    bicB <- BiclustResult(pp,L,Z,p)

    return(bicB)
}


indices<- function (bicA, bicB)
{
    require(truecluster)

    pA <- bicA@Number
    pB <- bicB@Number
    if ((pA>0)&&(pB>0)) {
        n <- length(bicA@RowxNumber[,1])
        l <- length(bicA@NumberxCol[1,])
        u <- n*l

        jamat <- matrix(0,pA,pB)
        kumat <- matrix(0,pA,pB)
        ocmat <- matrix(0,pA,pB)
        somat <- matrix(0,pA,pB)
        for (i in 1:pA) {
            bcA <- tcrossprod(bicA@RowxNumber[,i],bicA@NumberxCol[i,])
            apos <- bcA > 0
            sa <- sum(apos)
            if (sa > 0.5*u) {
                 bcA[apos] <- 0
                 sa <- 0
            }
            for (j in 1:pB) {
                bcB <- tcrossprod(bicB@RowxNumber[,j],bicB@NumberxCol[j,])
                bpos <- bcB > 0
                sb <- sum(bpos)
                if (sb > 0.5*u) {
                    bcB[bpos] <- 0
                    sb <- 0
                }
                bcAB <- bcA + bcB
                abpos <- bcAB > 0
                sab <- sum(abpos)

                if (sab>0) {
                    jamat[i,j] <- (sa + sb)/sab - 1
                    somat[i,j] <- 2.0-2.0*sab/(sa+sb)
                } else {
                    jamat[i,j] <- 0
                    somat[i,j] <- 0
                }
                if ((sa>0)&&(sb>0))
                {
                    kumat[i,j] <- 1.0+0.5*( (sa-sab)/sb + (sb -sab)/sa )
                    ocmat[i,j] <- (sa+sb-sab)/sqrt(sb*sa)
                }else {
                    kumat[i,j] <- 0
                    ocmat[i,j] <- 0
                }
            }
        }

        fac <- sqrt(pB*pA)

        mm <- min(pA,pB)
        ma <- max(pA,pB)

        sja <- sum(jamat)/fac
        sku <- sum(kumat)/fac
        soc <- sum(ocmat)/fac
        sso <- sum(somat)/fac

        indja <- munkres(-jamat,tieorder = FALSE)
        indku <- munkres(-kumat,tieorder = FALSE)
        indoc <- munkres(-ocmat,tieorder = FALSE)
        indso <- munkres(-somat,tieorder = FALSE)

        rjat <-  sum(diag(jamat[indja$row, indja$col]))
        rkut <-  sum(diag(kumat[indku$row, indku$col]))
        roct <-  sum(diag(ocmat[indoc$row, indoc$col]))
        rsot <-  sum(diag(somat[indso$row, indso$col]))

        rja <-  rjat/mm
        rku <-  rkut/mm
        roc <-  roct/mm
        rso <-  rsot/mm

        rja1 <-  rjat/ma
        rku1 <-  rkut/ma
        roc1 <-  roct/ma
        rso1 <-  rsot/ma
    } else {
        rja <- 0
        rku <- 0
        roc <- 0
        rso <- 0

        rja1 <- 0
        rku1 <- 0
        roc1 <- 0
        rso1 <- 0

        sja <- 0
        sku <- 0
        soc <- 0
        sso <- 0

    }



    return(as.vector(c(rja,rku,roc,rso,rja1,rku1,roc1,rso1,sja,sku,soc,sso)))
}

col_indices<- function (bicA, bicB)
{
    require(truecluster)

    pA <- bicA@Number
    pB <- bicB@Number
    if ((pA>0)&&(pB>0)) {
        l <- length(bicA@NumberxCol[1,])
        u <- l

        jamat <- matrix(0,pA,pB)
        kumat <- matrix(0,pA,pB)
        ocmat <- matrix(0,pA,pB)
        somat <- matrix(0,pA,pB)
        for (i in 1:pA) {
            bcA <- bicA@NumberxCol[i,]
            apos <- bcA > 0
            sa <- sum(apos)
            if (sa > 0.8*u) {
                 bcA[apos] <- 0
                 sa <- 0
            }
            for (j in 1:pB) {
                bcB <- bicB@NumberxCol[j,]
                bpos <- bcB > 0
                sb <- sum(bpos)
                if (sb > 0.8*u) {
                    bcB[bpos] <- 0
                    sb <- 0
                }
                bcAB <- bcA + bcB
                abpos <- bcAB > 0
                sab <- sum(abpos)

                if (sab>0) {
                    jamat[i,j] <- (sa + sb)/sab - 1
                    somat[i,j] <- 2.0-2.0*sab/(sa+sb)
                } else {
                    jamat[i,j] <- 0
                    somat[i,j] <- 0
                }
                if ((sa>0)&&(sb>0))
                {
                    kumat[i,j] <- 1.0+0.5*( (sa-sab)/sb + (sb -sab)/sa )
                    ocmat[i,j] <- (sa+sb-sab)/sqrt(sb*sa)
                }else {
                    kumat[i,j] <- 0
                    ocmat[i,j] <- 0
                }
            }
        }

        fac <- sqrt(pB*pA)

        mm <- min(pA,pB)
        ma <- max(pA,pB)

        sja <- sum(jamat)/fac
        sku <- sum(kumat)/fac
        soc <- sum(ocmat)/fac
        sso <- sum(somat)/fac

        indja <- munkres(-jamat,tieorder = FALSE)
        indku <- munkres(-kumat,tieorder = FALSE)
        indoc <- munkres(-ocmat,tieorder = FALSE)
        indso <- munkres(-somat,tieorder = FALSE)

        rjat <-  sum(diag(jamat[indja$row, indja$col]))
        rkut <-  sum(diag(kumat[indku$row, indku$col]))
        roct <-  sum(diag(ocmat[indoc$row, indoc$col]))
        rsot <-  sum(diag(somat[indso$row, indso$col]))

        rja <-  rjat/mm
        rku <-  rkut/mm
        roc <-  roct/mm
        rso <-  rsot/mm

        rja1 <-  rjat/ma
        rku1 <-  rkut/ma
        roc1 <-  roct/ma
        rso1 <-  rsot/ma
    } else {
        rja <- 0
        rku <- 0
        roc <- 0
        rso <- 0

        rja1 <- 0
        rku1 <- 0
        roc1 <- 0
        rso1 <- 0

        sja <- 0
        sku <- 0
        soc <- 0
        sso <- 0

    }



    return(as.vector(c(rja,rku,roc,rso,rja1,rku1,roc1,rso1,sja,sku,soc,sso)))
}



convertFabia <- function(rFab,n=1000,l=100,minc=5,minr=30,method="fabia",cyc=200,alpha=0.1,spl=1.0,spz=1.0,p=5,sL=0.0,sZ=0.0,La=NULL,Za=NULL,lapla=NULL,Psi=NULL)
{

    require(biclust)


    p <- length(rFab$bic[,1])

    pp <- 0
    for (i in 1:p) {
        if (rFab$bic[i,1]$binp[1]>=minr)
        {
            if (rFab$bic[i,1]$binp[2]>=minc) {
                pp <- pp + 1
            }
        }
    }

      if ((p==0)||(pp==0)) {
        L <- matrix(0,n,1)
        Z <- matrix(0,1,l)
        pp <- 0
    } else {


        L <- matrix(0,n,pp)
        Z <- matrix(0,pp,l)

        j <- 0

        for (i in 1:p) {

            if (rFab$bic[i,1]$binp[1]>=minr)
            {
                if (rFab$bic[i,1]$binp[2]>=minc) {
                    j <- j + 1
                    for (k in 1:rFab$bic[i,1]$binp[2]) {
                        Z[j,rFab$num[i,2]$numnp[k]] <- 1
                    }
                    for (k in 1:rFab$bic[i,1]$binp[1]) {
                        L[rFab$num[i,1]$numng[k],j] <- 1
                    }
                }
            }
        }
    }

    lp<- list()
    lp[[1]]=method
    lp[[2]]=cyc
    lp[[3]]=alpha
    lp[[4]]=spl
    lp[[5]]=spz
    lp[[6]]=p
    lp[[7]]=sL
    lp[[8]]=sZ
    lp[[9]]=La
    lp[[10]]=Za
    lp[[11]]=lapla
    lp[[12]]=Psi



    bicB <- BiclustResult(lp,L,Z,pp)

    return(bicB)
}


convertDat <- function(dat,n=1000,l=100)
{

    require(biclust)


    p <- length(dat$LC)

    L <- matrix(0,n,p)
    Z <- matrix(0,p,l)


    for (i in 1:p) {

        for (k in 1:length(dat$LC[[i]])) {
            L[dat$LC[[i]][k],i] <- 1
        }
        for (k in 1:length(dat$ZC[[i]])) {
            Z[i,dat$ZC[[i]][k]] <- 1
        }
    }


    lp<- list()
    lp[[1]]="make_fabi_data"
    lp[[2]]=n
    lp[[3]]=l

    bicB <- BiclustResult(lp,L,Z,p)

    return(bicB)
}

#=====================================================================
#=====================================================================

alpha_fabia = 0.1
alpha_fabias = 0.4
spl=1.0
spz=1.0
cyc=200
p=5


#=====================================================================
#=====================================================================
    data(Breast_A)

    l <- ncol(XBreast)
    n <- nrow(XBreast)

    porg <- 3

    La <- matrix(1,n,porg)
    Za <- matrix(0,porg,l)


    for (i in 1:porg) {
        Za[i,which(CBreast==i)] <- 1
    }


    lp<- list()
    lp[[1]]="breast_data"
    lp[[2]]=n
    lp[[3]]=l

    breast_biclust <- BiclustResult(lp,La,Za,porg)


    save(breast_biclust,file="exp_breast_Biclust_orig.RData")

    X <- as.matrix(XBreast)
    X <- X- rowMeans(X)
    XX <- (1/ncol(X))*tcrossprod(X)
    dXX <- 1/sqrt(diag(XX)+0.001*as.vector(rep(1,nrow(X))))
    X <- dXX*X



    resFab <- fabia(X,cyc,alpha_fabia,spl,spz,p)

    rFab <- extract_bic(resFab$L,resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    rfabia <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="fabia",cyc=cyc,alpha=alpha_fabia,spl=spl,spz=spz,p=p,sL=0.0,sZ=0.0,L=resFab$L,Z=resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    save(rfabia,file="exp_breast_Biclust_fabia.RData")

    resFab <- fabias(X,cyc,alpha_fabias,spz,p)

    rFab <- extract_bic(resFab$L,resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    rfabias <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="fabias",cyc=cyc,alpha=alpha_fabias,spl=0,spz=spz,p=5,sL=0.0,sZ=0.0,L=resFab$L,Z=resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    save(rfabias,file="exp_breast_Biclust_fabias.RData")

    resFab <- fabiap(X,cyc,alpha_fabia,spl,spz,p,alpha_fabias,alpha_fabias)

    rFab <- extract_bic(resFab$L,resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    rfabiap <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="fabiap",cyc=cyc,alpha=alpha_fabia,spl=spl,spz=spz,p=5,sL=alpha_fabias,sZ=alpha_fabias,L=resFab$L,Z=resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    save(rfabiap,file="exp_breast_Biclust_fabiap.RData")

    resFab <- mfsc(X,p,alpha_fabias,alpha_fabias)

    rFab <- extract_bic(resFab$L,resFab$Z)

    rmfsc <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="mfsc",cyc=0,alpha=0,spl=0,spz=0,p=p,sL=alpha_fabias,sZ=alpha_fabias,L=resFab$L,Z=resFab$Z,lapla=NULL,Psi=NULL)

    save(rmfsc,file="exp_breast_Biclust_mfsc.RData")

    rplaid_ss<- readPlaidResults("exp_breast_plaid_ss.res",n,l,ab="ab",ss="ss",iter="default")

    save(rplaid_ss,file="exp_breast_Biclust_plaid_ss.RData")

    rplaid_ms<- readPlaidResults("exp_breast_plaid_ms.res",n,l,ab="ab",ss="ms",iter="default")

    save(rplaid_ms,file="exp_breast_Biclust_plaid_ms.RData")

    rplaid_ms_5 <- readPlaidResults("exp_breast_plaid_ms_5.res",n,l,ab="ab",ss="ms",iter="5")

    save(rplaid_ms_5,file="exp_breast_Biclust_plaid_ms_5.RData")

    rplaid_a_ss<- readPlaidResults("exp_breast_plaid_a_ss.res",n,l,ab="ab",ss="ss",iter="default")

    save(rplaid_a_ss,file="exp_breast_Biclust_plaid_a_ss.RData")

    rplaid_a_ms<- readPlaidResults("exp_breast_plaid_a_ms.res",n,l,ab="ab",ss="ms",iter="default")

    save(rplaid_a_ms,file="exp_breast_Biclust_plaid_a_ms.RData")

    rplaid_a_ms_5 <- readPlaidResults("exp_breast_plaid_a_ms_5.res",n,l,ab="ab",ss="ms",iter="5")

    save(rplaid_a_ms_5,file="exp_breast_Biclust_plaid_a_ms_5.RData")

    risa <- readBicatResults("exp_breast_isa.res",n,l,method="isa",pre="standardization",tc="2.0",tg="2.0")

    save(risa,file="exp_breast_Biclust_isa.RData")

    risa_1 <- readBicatResults("exp_breast_isa_1.res",n,l,method="isa",pre="standardization",tc="1.0",tg="1.0")

    save(risa_1,file="exp_breast_Biclust_isa_1.RData")

    ropsm <- readBicatResults("exp_breast_opsm.res",n,l,method="opsm",pre="standardization",tc="",tg="")

    save(ropsm,file="exp_breast_Biclust_opsm.RData")

    rsamba_01<- readSambaResults("exp_breast_samba_01.res",n,l,pre="standardization",opt="valsp_3ap",over="0.1")

    save(rsamba_01,file="exp_breast_Biclust_samba_01.RData")

    rsamba_05 <- readSambaResults("exp_breast_samba_05.res",n,l,pre="standardization",opt="valsp_3ap",over="0.5")

    save(rsamba_05,file="exp_breast_Biclust_samba_05.RData")

    XD<-discretize(X)
    rxmotif <- biclust(XD, method=BCXmotifs(), ns=100, nd=100, sd=5, alpha=0.05, number=5)

    save(rxmotif,file="exp_breast_Biclust_xmotif.RData")



    XB <- binarize(X)
    rbimax <- biclust(XB, method=BCBimax(), minr=30, minc=5, number=5)
    save(rbimax,file="exp_breast_Biclust_bimax.RData")


    rcc <- biclust(X, method=BCCC(), delta=0.03,  alpha=1.2, number=5)
    save(rcc,file="exp_breast_Biclust_cc.RData")


    rplaid_t_ab <- biclust(X, method=BCPlaid(), cluster="b", fit.model = y ~ m + a + b, background = TRUE, row.release = 0.7, col.release = 0.7,shuffle = 3, back.fit = 0, max.layers = 5, iter.startup = 5, iter.layer = 10, verbose = TRUE)
    save(rplaid_t_ab,file="exp_breast_Biclust_plaid_t_ab.RData")

    rplaid_t_a <- biclust(X, method=BCPlaid(), cluster="b", fit.model = y ~ m + a, background = TRUE, row.release = 0.7, col.release = 0.7,shuffle = 3, back.fit = 0, max.layers = 5,iter.startup = 5, iter.layer = 10, verbose = TRUE)
    save(rplaid_t_a,file="exp_breast_Biclust_plaid_t_a.RData")



    rspec <- biclust(exp(X), method=BCSpectral(), normalization="log", numberOfEigenvalues=6, minr=30, minc=5, withinVar=1)
    save(rspec,file="exp_breast_Biclust_spec.RData")



    resfloc <- FLOC(X, k = 5, pGene = 0.1, pSample=0.1, N = 30, M = 5, t = 500)


    rfloc <- BiclustResult(as.list(resfloc$param),t(resfloc$bicRow),resfloc$bicCol,as.numeric(resfloc$param[1,2]))
    save(rfloc,file="exp_breast_Biclust_floc.RData")


    indrfabia<-col_indices(breast_biclust,rfabia)
    indrfabias<-col_indices(breast_biclust,rfabias)
    indrfabiap<-col_indices(breast_biclust,rfabiap)
    indrmfsc<-col_indices(breast_biclust,rmfsc)
    indrplaid_ss<-col_indices(breast_biclust,rplaid_ss)
    indrplaid_ms<-col_indices(breast_biclust,rplaid_ms)
    indrplaid_ms_5<-col_indices(breast_biclust,rplaid_ms_5)
    indrplaid_a_ss<-col_indices(breast_biclust,rplaid_a_ss)
    indrplaid_a_ms<-col_indices(breast_biclust,rplaid_a_ms)
    indrplaid_a_ms_5<-col_indices(breast_biclust,rplaid_a_ms_5)
    indrisa<-col_indices(breast_biclust,risa)
    indrisa_1<-col_indices(breast_biclust,risa_1)
    indropsm<-col_indices(breast_biclust,ropsm)
    indrsamba_01<-col_indices(breast_biclust,rsamba_01)
    indrsamba_05<-col_indices(breast_biclust,rsamba_05)
    indrxmotif<-col_indices(breast_biclust,rxmotif)
    indrbimax<-col_indices(breast_biclust,rbimax)
    indrcc<-col_indices(breast_biclust,rcc)
    indrplaid_t_ab<-col_indices(breast_biclust,rplaid_t_ab)
    indrplaid_t_a<-col_indices(breast_biclust,rplaid_t_a)
    indrspec<-col_indices(breast_biclust,rspec)
    indrfloc<-col_indices(breast_biclust,rfloc)

    save(indrfabia,indrfabias,indrfabiap,indrmfsc,indrplaid_ss,indrplaid_ms,indrplaid_ms_5,indrplaid_a_ss,indrplaid_a_ms,indrplaid_a_ms_5,indrisa,indrisa_1,indropsm,indrsamba_01,indrsamba_05,indrxmotif,indrbimax,indrcc,indrplaid_t_ab,indrplaid_t_a,indrspec,indrfloc,file="exp_breast_ind_res.RData")

     write.table(t(as.vector(indrfabia)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =FALSE)
     write.table(t(as.vector(indrfabias)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrfabiap)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrmfsc)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_ss)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_ms)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_ms_5)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_a_ss)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_a_ms)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_a_ms_5)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrisa)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrisa_1)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indropsm)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrsamba_01)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrsamba_05)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrxmotif)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrbimax)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrcc)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_t_ab)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_t_a)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrspec)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrfloc)), file = "exp_breast_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)

#=====================================================================
#=====================================================================

    data(Multi_A)

    l <- ncol(XMulti)
    n <- nrow(XMulti)

    porg <- 4

    La <- matrix(1,n,porg)
    Za <- matrix(0,porg,l)


    for (i in 1:porg) {
        Za[i,which(CMulti==i)] <- 1
    }


    lp<- list()
    lp[[1]]="multi_data"
    lp[[2]]=n
    lp[[3]]=l

    multi_biclust <- BiclustResult(lp,La,Za,porg)


    save(multi_biclust,file="exp_multi_Biclust_orig.RData")

    X <- as.matrix(XMulti)
    X <- X- rowMeans(X)
    XX <- (1/ncol(X))*tcrossprod(X)
    dXX <- 1/sqrt(diag(XX)+0.001*as.vector(rep(1,nrow(X))))
    X <- dXX*X



    resFab <- fabia(X,cyc,alpha_fabia,spl,spz,5)

    rFab <- extract_bic(resFab$L,resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    rfabia <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="fabia",cyc=cyc,alpha=alpha_fabia,spl=spl,spz=spz,p=p,sL=0.0,sZ=0.0,L=resFab$L,Z=resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    save(rfabia,file="exp_multi_Biclust_fabia.RData")

    resFab <- fabias(X,cyc,alpha_fabias,spz,p)

    rFab <- extract_bic(resFab$L,resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    rfabias <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="fabias",cyc=cyc,alpha=alpha_fabias,spl=0,spz=spz,p=p,sL=0.0,sZ=0.0,L=resFab$L,Z=resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    save(rfabias,file="exp_multi_Biclust_fabias.RData")

    resFab <- fabiap(X,cyc,alpha_fabia,spl,spz,p,alpha_fabias,alpha_fabias)

    rFab <- extract_bic(resFab$L,resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    rfabiap <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="fabiap",cyc=cyc,alpha=alpha_fabia,spl=spl,spz=spz,p=5,sL=alpha_fabias,sZ=alpha_fabias,L=resFab$L,Z=resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    save(rfabiap,file="exp_multi_Biclust_fabiap.RData")

    resFab <- mfsc(X,p,alpha_fabias,alpha_fabias)

    rFab <- extract_bic(resFab$L,resFab$Z)

    rmfsc <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="mfsc",cyc=0,alpha=0,spl=0,spz=0,p=p,sL=alpha_fabias,sZ=alpha_fabias,L=resFab$L,Z=resFab$Z,lapla=NULL,Psi=NULL)

    save(rmfsc,file="exp_multi_Biclust_mfsc.RData")

    rplaid_ss<- readPlaidResults("exp_multi_plaid_ss.res",n,l,ab="ab",ss="ss",iter="default")

    save(rplaid_ss,file="exp_multi_Biclust_plaid_ss.RData")

    rplaid_ms<- readPlaidResults("exp_multi_plaid_ms.res",n,l,ab="ab",ss="ms",iter="default")

    save(rplaid_ms,file="exp_multi_Biclust_plaid_ms.RData")

    rplaid_ms_5 <- readPlaidResults("exp_multi_plaid_ms_5.res",n,l,ab="ab",ss="ms",iter="5")

    save(rplaid_ms_5,file="exp_multi_Biclust_plaid_ms_5.RData")

    rplaid_a_ss<- readPlaidResults("exp_multi_plaid_a_ss.res",n,l,ab="ab",ss="ss",iter="default")

    save(rplaid_a_ss,file="exp_multi_Biclust_plaid_a_ss.RData")

    rplaid_a_ms<- readPlaidResults("exp_multi_plaid_a_ms.res",n,l,ab="ab",ss="ms",iter="default")

    save(rplaid_a_ms,file="exp_multi_Biclust_plaid_a_ms.RData")

    rplaid_a_ms_5 <- readPlaidResults("exp_multi_plaid_a_ms_5.res",n,l,ab="ab",ss="ms",iter="5")

    save(rplaid_a_ms_5,file="exp_multi_Biclust_plaid_a_ms_5.RData")

    risa <- readBicatResults("exp_multi_isa.res",n,l,method="isa",pre="standardization",tc="2.0",tg="2.0")

    save(risa,file="exp_multi_Biclust_isa.RData")

    risa_1 <- readBicatResults("exp_multi_isa_1.res",n,l,method="isa",pre="standardization",tc="1.0",tg="1.0")

    save(risa_1,file="exp_multi_Biclust_isa_1.RData")

    ropsm <- readBicatResults("exp_multi_opsm.res",n,l,method="opsm",pre="standardization",tc="",tg="")

    save(ropsm,file="exp_multi_Biclust_opsm.RData")

    rsamba_01<- readSambaResults("exp_multi_samba_01.res",n,l,pre="standardization",opt="valsp_3ap",over="0.1")

    save(rsamba_01,file="exp_multi_Biclust_samba_01.RData")

    rsamba_05 <- readSambaResults("exp_multi_samba_05.res",n,l,pre="standardization",opt="valsp_3ap",over="0.5")

    save(rsamba_05,file="exp_multi_Biclust_samba_05.RData")

    XD<-discretize(X)
    rxmotif <- biclust(XD, method=BCXmotifs(), ns=100, nd=100, sd=5, alpha=0.05, number=5)

    save(rxmotif,file="exp_multi_Biclust_xmotif.RData")



    XB <- binarize(X)
    rbimax <- biclust(XB, method=BCBimax(), minr=30, minc=5, number=5)
    save(rbimax,file="exp_multi_Biclust_bimax.RData")


#    rcc <- biclust(X, method=BCCC(), delta=0.03,  alpha=1.2, number=5)
#    save(rcc,file="exp_multi_Biclust_cc.RData")


    rplaid_t_ab <- biclust(X, method=BCPlaid(), cluster="b", fit.model = y ~ m + a + b, background = TRUE, row.release = 0.7, col.release = 0.7,shuffle = 3, back.fit = 0, max.layers = 5, iter.startup = 5, iter.layer = 10, verbose = TRUE)
    save(rplaid_t_ab,file="exp_multi_Biclust_plaid_t_ab.RData")

    rplaid_t_a <- biclust(X, method=BCPlaid(), cluster="b", fit.model = y ~ m + a, background = TRUE, row.release = 0.7, col.release = 0.7,shuffle = 3, back.fit = 0, max.layers = 5,iter.startup = 5, iter.layer = 10, verbose = TRUE)
    save(rplaid_t_a,file="exp_multi_Biclust_plaid_t_a.RData")



    rspec <- biclust(exp(X), method=BCSpectral(), normalization="log", numberOfEigenvalues=6, minr=30, minc=5, withinVar=1)
    save(rspec,file="exp_multi_Biclust_spec.RData")



#    resfloc <- FLOC(X, k = 5, pGene = 0.1, pSample=0.1, N = 30, M = 5, t = 500)


#    rfloc <- BiclustResult(as.list(resfloc$param),t(resfloc$bicRow),resfloc$bicCol,as.numeric(resfloc$param[1,2]))
#    save(rfloc,file="exp_multi_Biclust_floc.RData")


    indrfabia<-col_indices(multi_biclust,rfabia)
    indrfabias<-col_indices(multi_biclust,rfabias)
    indrfabiap<-col_indices(multi_biclust,rfabiap)
    indrmfsc<-col_indices(multi_biclust,rmfsc)
    indrplaid_ss<-col_indices(multi_biclust,rplaid_ss)
    indrplaid_ms<-col_indices(multi_biclust,rplaid_ms)
    indrplaid_ms_5<-col_indices(multi_biclust,rplaid_ms_5)
    indrplaid_a_ss<-col_indices(multi_biclust,rplaid_a_ss)
    indrplaid_a_ms<-col_indices(multi_biclust,rplaid_a_ms)
    indrplaid_a_ms_5<-col_indices(multi_biclust,rplaid_a_ms_5)
    indrisa<-col_indices(multi_biclust,risa)
    indrisa_1<-col_indices(multi_biclust,risa_1)
    indropsm<-col_indices(multi_biclust,ropsm)
    indrsamba_01<-col_indices(multi_biclust,rsamba_01)
    indrsamba_05<-col_indices(multi_biclust,rsamba_05)
    indrxmotif<-col_indices(multi_biclust,rxmotif)
    indrbimax<-col_indices(multi_biclust,rbimax)
#    indrcc<-col_indices(multi_biclust,rcc)
    indrplaid_t_ab<-col_indices(multi_biclust,rplaid_t_ab)
    indrplaid_t_a<-col_indices(multi_biclust,rplaid_t_a)
    indrspec<-col_indices(multi_biclust,rspec)
#    indrfloc<-col_indices(multi_biclust,rfloc)

    save(indrfabia,indrfabias,indrfabiap,indrmfsc,indrplaid_ss,indrplaid_ms,indrplaid_ms_5,indrplaid_a_ss,indrplaid_a_ms,indrplaid_a_ms_5,indrisa,indrisa_1,indropsm,indrsamba_01,indrsamba_05,indrxmotif,indrbimax,indrcc,indrplaid_t_ab,indrplaid_t_a,indrspec,indrfloc,file="exp_multi_ind_res.RData")

     write.table(t(as.vector(indrfabia)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =FALSE)
     write.table(t(as.vector(indrfabias)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrfabiap)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrmfsc)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_ss)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_ms)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_ms_5)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_a_ss)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_a_ms)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_a_ms_5)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrisa)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrisa_1)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indropsm)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrsamba_01)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrsamba_05)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrxmotif)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrbimax)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
#     write.table(t(as.vector(indrcc)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_t_ab)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_t_a)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrspec)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
#     write.table(t(as.vector(indrfloc)), file = "exp_multi_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)

#=====================================================================
#=====================================================================

    data(DLBCL_B)

    l <- ncol(XDLBCL)
    n <- nrow(XDLBCL)

    porg <- 3

    La <- matrix(1,n,porg)
    Za <- matrix(0,porg,l)


    for (i in 1:porg) {
        Za[i,which(CDLBCL==i)] <- 1
    }


    lp<- list()
    lp[[1]]="dlbcl_data"
    lp[[2]]=n
    lp[[3]]=l

    dlbcl_biclust <- BiclustResult(lp,La,Za,porg)


    save(dlbcl_biclust,file="exp_dlbcl_Biclust_orig.RData")

    X <- as.matrix(XDLBCL)
    X <- X- rowMeans(X)
    XX <- (1/ncol(X))*tcrossprod(X)
    dXX <- 1/sqrt(diag(XX)+0.001*as.vector(rep(1,nrow(X))))
    X <- dXX*X


    resFab <- fabia(X,cyc,alpha_fabia,spl,spz,p)

    rFab <- extract_bic(resFab$L,resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    rfabia <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="fabia",cyc=cyc,alpha=alpha_fabia,spl=spl,spz=spz,p=p,sL=0.0,sZ=0.0,L=resFab$L,Z=resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    save(rfabia,file="exp_dlbcl_Biclust_fabia.RData")

    resFab <- fabias(X,cyc,alpha_fabias,spz,p)

    rFab <- extract_bic(resFab$L,resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    rfabias <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="fabias",cyc=cyc,alpha=alpha_fabias,spl=0,spz=spz,p=p,sL=0.0,sZ=0.0,L=resFab$L,Z=resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    save(rfabias,file="exp_dlbcl_Biclust_fabias.RData")

    resFab <- fabiap(X,cyc,alpha_fabia,spl,spz,ww,alpha_fabias,alpha_fabias)

    rFab <- extract_bic(resFab$L,resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    rfabiap <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="fabiap",cyc=cyc,alpha=alpha_fabia,spl=spl,spz=spz,p=p,sL=alpha_fabias,sZ=alpha_fabias,L=resFab$L,Z=resFab$Z,lapla=resFab$lapla,Psi=resFab$Psi)

    save(rfabiap,file="exp_dlbcl_Biclust_fabiap.RData")

    resFab <- mfsc(X,p,alpha_fabias,alpha_fabias)

    rFab <- extract_bic(resFab$L,resFab$Z)

    rmfsc <- convertFabia(rFab,n=n,l=l,minc=5,minr=30,method="mfsc",cyc=0,alpha=0,spl=0,spz=0,p=p,sL=alpha_fabias,sZ=alpha_fabias,L=resFab$L,Z=resFab$Z,lapla=NULL,Psi=NULL)

    save(rmfsc,file="exp_dlbcl_Biclust_mfsc.RData")

    rplaid_ss<- readPlaidResults("exp_dlbcl_plaid_ss.res",n,l,ab="ab",ss="ss",iter="default")

    save(rplaid_ss,file="exp_dlbcl_Biclust_plaid_ss.RData")

    rplaid_ms<- readPlaidResults("exp_dlbcl_plaid_ms.res",n,l,ab="ab",ss="ms",iter="default")

    save(rplaid_ms,file="exp_dlbcl_Biclust_plaid_ms.RData")

    rplaid_ms_5 <- readPlaidResults("exp_dlbcl_plaid_ms_5.res",n,l,ab="ab",ss="ms",iter="5")

    save(rplaid_ms_5,file="exp_dlbcl_Biclust_plaid_ms_5.RData")

    rplaid_a_ss<- readPlaidResults("exp_dlbcl_plaid_a_ss.res",n,l,ab="ab",ss="ss",iter="default")

    save(rplaid_a_ss,file="exp_dlbcl_Biclust_plaid_a_ss.RData")

    rplaid_a_ms<- readPlaidResults("exp_dlbcl_plaid_a_ms.res",n,l,ab="ab",ss="ms",iter="default")

    save(rplaid_a_ms,file="exp_dlbcl_Biclust_plaid_a_ms.RData")

    rplaid_a_ms_5 <- readPlaidResults("exp_dlbcl_plaid_a_ms_5.res",n,l,ab="ab",ss="ms",iter="5")

    save(rplaid_a_ms_5,file="exp_dlbcl_Biclust_plaid_a_ms_5.RData")

    risa <- readBicatResults("exp_dlbcl_isa.res",n,l,method="isa",pre="standardization",tc="2.0",tg="2.0")

    save(risa,file="exp_dlbcl_Biclust_isa.RData")

    risa_1 <- readBicatResults("exp_dlbcl_isa_1.res",n,l,method="isa",pre="standardization",tc="1.0",tg="1.0")

    save(risa_1,file="exp_dlbcl_Biclust_isa_1.RData")

    ropsm <- readBicatResults("exp_dlbcl_opsm.res",n,l,method="opsm",pre="standardization",tc="",tg="")

    save(ropsm,file="exp_dlbcl_Biclust_opsm.RData")

    rsamba_01 <- readSambaResults("exp_dlbcl_samba_01.res",n,l,pre="standardization",opt="valsp_3ap",over="0.5")

    save(rsamba_01,file="exp_dlbcl_Biclust_samba_01.RData")

    rsamba_05 <- readSambaResults("exp_dlbcl_samba_05.res",n,l,pre="standardization",opt="valsp_3ap",over="0.5")

    save(rsamba_05,file="exp_dlbcl_Biclust_samba_05.RData")

    XD<-discretize(X)
    rxmotif <- biclust(XD, method=BCXmotifs(), ns=100, nd=100, sd=5, alpha=0.05, number=5)

    save(rxmotif,file="exp_dlbcl_Biclust_xmotif.RData")



    XB <- binarize(X)
    rbimax <- biclust(XB, method=BCBimax(), minr=30, minc=5, number=5)
    save(rbimax,file="exp_dlbcl_Biclust_bimax.RData")


    rcc <- biclust(X, method=BCCC(), delta=0.03,  alpha=1.2, number=5)
    save(rcc,file="exp_dlbcl_Biclust_cc.RData")


    rplaid_t_ab <- biclust(X, method=BCPlaid(), cluster="b", fit.model = y ~ m + a + b, background = TRUE, row.release = 0.7, col.release = 0.7,shuffle = 3, back.fit = 0, max.layers = 5, iter.startup = 5, iter.layer = 10, verbose = TRUE)
    save(rplaid_t_ab,file="exp_dlbcl_Biclust_plaid_t_ab.RData")

    rplaid_t_a <- biclust(X, method=BCPlaid(), cluster="b", fit.model = y ~ m + a, background = TRUE, row.release = 0.7, col.release = 0.7,shuffle = 3, back.fit = 0, max.layers = 5,iter.startup = 5, iter.layer = 10, verbose = TRUE)
    save(rplaid_t_a,file="exp_dlbcl_Biclust_plaid_t_a.RData")



    rspec <- biclust(exp(X), method=BCSpectral(), normalization="log", numberOfEigenvalues=6, minr=30, minc=5, withinVar=1)
    save(rspec,file="exp_dlbcl_Biclust_spec.RData")



    resfloc <- FLOC(X, k = 5, pGene = 0.1, pSample=0.1, N = 30, M = 5, t = 500)


    rfloc <- BiclustResult(as.list(resfloc$param),t(resfloc$bicRow),resfloc$bicCol,as.numeric(resfloc$param[1,2]))
    save(rfloc,file="exp_dlbcl_Biclust_floc.RData")


    indrfabia<-col_indices(dlbcl_biclust,rfabia)
    indrfabias<-col_indices(dlbcl_biclust,rfabias)
    indrfabiap<-col_indices(dlbcl_biclust,rfabiap)
    indrmfsc<-col_indices(dlbcl_biclust,rmfsc)
    indrplaid_ss<-col_indices(dlbcl_biclust,rplaid_ss)
    indrplaid_ms<-col_indices(dlbcl_biclust,rplaid_ms)
    indrplaid_ms_5<-col_indices(dlbcl_biclust,rplaid_ms_5)
    indrplaid_a_ss<-col_indices(dlbcl_biclust,rplaid_a_ss)
    indrplaid_a_ms<-col_indices(dlbcl_biclust,rplaid_a_ms)
    indrplaid_a_ms_5<-col_indices(dlbcl_biclust,rplaid_a_ms_5)
    indrisa<-col_indices(dlbcl_biclust,risa)
    indrisa_1<-col_indices(dlbcl_biclust,risa_1)
    indropsm<-col_indices(dlbcl_biclust,ropsm)
    indrsamba_01<-col_indices(dlbcl_biclust,rsamba_01)
    indrsamba_05<-col_indices(dlbcl_biclust,rsamba_05)
    indrxmotif<-col_indices(dlbcl_biclust,rxmotif)
    indrbimax<-col_indices(dlbcl_biclust,rbimax)
    indrcc<-col_indices(dlbcl_biclust,rcc)
    indrplaid_t_ab<-col_indices(dlbcl_biclust,rplaid_t_ab)
    indrplaid_t_a<-col_indices(dlbcl_biclust,rplaid_t_a)
    indrspec<-col_indices(dlbcl_biclust,rspec)
    indrfloc<-col_indices(dlbcl_biclust,rfloc)

    save(indrfabia,indrfabias,indrfabiap,indrmfsc,indrplaid_ss,indrplaid_ms,indrplaid_ms_5,indrplaid_a_ss,indrplaid_a_ms,indrplaid_a_ms_5,indrisa,indrisa_1,indropsm,indrsamba_01,indrsamba_05,indrxmotif,indrbimax,indrcc,indrplaid_t_ab,indrplaid_t_a,indrspec,indrfloc,file="exp_dlbcl_ind_res.RData")

     write.table(t(as.vector(indrfabia)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =FALSE)
     write.table(t(as.vector(indrfabias)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrfabiap)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrmfsc)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_ss)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_ms)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_ms_5)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_a_ss)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_a_ms)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_a_ms_5)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrisa)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrisa_1)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indropsm)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrsamba_01)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrsamba_05)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrxmotif)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrbimax)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrcc)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_t_ab)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrplaid_t_a)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrspec)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)
     write.table(t(as.vector(indrfloc)), file = "exp_dlbcl_in_res.txt", quote = FALSE, sep = "\t",row.names = FALSE,col.names = FALSE,append =TRUE)

